@@ -12,8 +12,9 @@ import math
 import secrets
 import struct
 import time
+from collections.abc import Callable, Coroutine
 from random import randint
-from typing import Any, Callable, Coroutine, Optional, Type, TypeVar, final
+from typing import Any, TypeVar, final
 
 import aiohttp
 
@@ -69,7 +70,6 @@ from .util import RepeatableTask, RoborockLoggerAdapter, get_running_loop_or_cre
 
 _LOGGER = logging.getLogger(__name__)
 KEEPALIVE = 60
-QUEUE_TIMEOUT = 4
 COMMANDS_SECURED = [
     RoborockCommand.GET_MAP_V1,
     RoborockCommand.GET_MULTI_MAP,
@@ -89,7 +89,7 @@ def md5hex(message: str) -> str:
 
 
 class PreparedRequest:
-    def __init__(self, base_url: str, base_headers: Optional[dict] = None) -> None:
+    def __init__(self, base_url: str, base_headers: dict | None = None) -> None:
         self.base_url = base_url
         self.base_headers = base_headers or {}
 
@@ -165,7 +165,7 @@ device_cache: dict[str, dict[CacheableAttribute, AttributeCache]] = {}
 
 
 class RoborockClient:
-    def __init__(self, endpoint: str, device_info: DeviceData) -> None:
+    def __init__(self, endpoint: str, device_info: DeviceData, queue_timeout: int = 4) -> None:
         self.event_loop = get_running_loop_or_create_one()
         self.device_info = device_info
         self._endpoint = endpoint
@@ -184,6 +184,8 @@ class RoborockClient:
             device_cache[device_info.device.duid] = cache
         self.cache: dict[CacheableAttribute, AttributeCache] = cache
         self._listeners: list[Callable[[str, CacheableAttribute, RoborockBase], None]] = []
+        self.is_available: bool = False
+        self.queue_timeout = queue_timeout
 
     def __del__(self) -> None:
         self.release()
@@ -251,7 +253,7 @@ class RoborockClient:
                                 data_protocol = RoborockDataProtocol(int(data_point_number))
                                 self._logger.debug(f"Got device update for {data_protocol.name}: {data_point}")
                                 if data_protocol in ROBOROCK_DATA_STATUS_PROTOCOL:
-                                    _cls: Type[Status] = ModelStatus.get(
+                                    _cls: type[Status] = ModelStatus.get(
                                         self.device_info.model, S7MaxVStatus
                                     )  # Default to S7 MAXV if we don't have the data
                                     if self.cache[CacheableAttribute.status].value is None:
@@ -301,7 +303,7 @@ class RoborockClient:
         except Exception as ex:
             self._logger.exception(ex)
 
-    def on_connection_lost(self, exc: Optional[Exception]) -> None:
+    def on_connection_lost(self, exc: Exception | None) -> None:
         self._last_disconnection = self.time_func()
         self._logger.info("Roborock client disconnected")
         if exc is not None:
@@ -321,12 +323,12 @@ class RoborockClient:
 
     async def _wait_response(self, request_id: int, queue: RoborockFuture) -> tuple[Any, VacuumError | None]:
         try:
-            (response, err) = await queue.async_get(QUEUE_TIMEOUT)
+            (response, err) = await queue.async_get(self.queue_timeout)
             if response == "unknown_method":
                 raise UnknownMethodError("Unknown method")
             return response, err
         except (asyncio.TimeoutError, asyncio.CancelledError):
-            raise RoborockTimeout(f"id={request_id} Timeout after {QUEUE_TIMEOUT} seconds") from None
+            raise RoborockTimeout(f"id={request_id} Timeout after {self.queue_timeout} seconds") from None
         finally:
             self._waiting_queue.pop(request_id, None)
 
@@ -340,7 +342,7 @@ class RoborockClient:
     def _get_payload(
         self,
         method: RoborockCommand,
-        params: Optional[list | dict] = None,
+        params: list | dict | None = None,
         secured=False,
     ):
         timestamp = math.floor(time.time())
@@ -372,7 +374,7 @@ class RoborockClient:
     async def _send_command(
         self,
         method: RoborockCommand,
-        params: Optional[list | dict] = None,
+        params: list | dict | None = None,
     ):
         raise NotImplementedError
 
@@ -380,8 +382,8 @@ class RoborockClient:
     async def send_command(
         self,
         method: RoborockCommand,
-        params: Optional[list | dict] = None,
-        return_type: Optional[Type[RT]] = None,
+        params: list | dict | None = None,
+        return_type: type[RT] | None = None,
     ) -> RT:
         cacheable_attribute_result = find_cacheable_attribute(method)
 
@@ -404,7 +406,7 @@ class RoborockClient:
         return response
 
     async def get_status(self) -> Status | None:
-        _cls: Type[Status] = ModelStatus.get(
+        _cls: type[Status] = ModelStatus.get(
             self.device_info.model, S7MaxVStatus
         )  # Default to S7 MAXV if we don't have the data
         return _cls.from_dict(await self.cache[CacheableAttribute.status].async_value())
